@@ -29,8 +29,7 @@
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 #include <gconf/gconf-client.h>
-#include <libgnomevfs/gnome-vfs.h>
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
+#include <gio/gio.h>
 #include <string.h>
 
 #include "totem-uri.h"
@@ -259,17 +258,24 @@ totem_playlist_error (char *title, char *reason, TotemPlaylist *playlist)
 	gtk_widget_show (error_dialog);
 }
 
-/* This one returns a new string, in UTF8 even if the mrl is encoded
+/* This one returns a new string, in UTF8 even if the MRL is encoded
  * in the locale's encoding
  */
 static char *
 totem_playlist_mrl_to_title (const gchar *mrl)
 {
-	char *filename_for_display, *filename, *unescaped;
+	GFile *file;
+	char *filename_for_display, *unescaped;
 
-	filename = g_path_get_basename (mrl);
-	unescaped = gnome_vfs_unescape_string_for_display (filename);
-	g_free (filename);
+	if (g_str_has_prefix (mrl, "dvd://") != FALSE) {
+		/* This is "Title 3", where title is a DVD title
+		 * Note: NOT a DVD chapter */
+		return g_strdup_printf (_("Title %d"), (int) g_strtod (mrl + 6, NULL));
+	}
+
+	file = g_file_new_for_uri (mrl);
+	unescaped = g_file_get_basename (file);
+	g_object_unref (file);
 
 	filename_for_display = g_filename_to_utf8 (unescaped,
 			-1,             /* length */
@@ -374,29 +380,20 @@ drop_cb (GtkWidget        *widget,
 	 guint             time, 
 	 TotemPlaylist    *playlist)
 {
-	GList *list, *p, *file_list;
+	char **list;
+	GList *p, *file_list;
+	guint i;
 
-	list = gnome_vfs_uri_list_parse ((char *)data->data);
-
-	if (list == NULL) {
-		gtk_drag_finish (context, FALSE, FALSE, time);
-		return;
-	}
-
-	p = list;
+	list = g_uri_list_extract_uris ((char *)data->data);
 	file_list = NULL;
 
-	while (p != NULL) {
+	for (i = 0; list[i] != NULL; i++) {
 		/* We get the list in the wrong order here,
 		 * so when we insert the files at the same position
 		 * in the tree, they are in the right order.*/
-		file_list = g_list_prepend (file_list,
-					    gnome_vfs_uri_to_string ((const GnomeVFSURI*)(p->data), 0));
-		p = p->next;
+		file_list = g_list_prepend (file_list, list[i]);
 	}
 
-	gnome_vfs_uri_list_free (list);
-
 	if (file_list == NULL) {
 		gtk_drag_finish (context, FALSE, FALSE, time);
 		return;
@@ -427,7 +424,6 @@ drop_cb (GtkWidget        *widget,
 		title = NULL;
 
 		if (info == 1) {
-			g_free (p->data);
 			p = p->next;
 			if (p != NULL) {
 				if (g_str_has_prefix (p->data, "file:") != FALSE)
@@ -440,9 +436,9 @@ drop_cb (GtkWidget        *widget,
 		totem_playlist_add_mrl (playlist, filename, title);
 
 		g_free (filename);
-		g_free (p->data);
 	}
 
+	g_strfreev (list);
 	g_list_free (file_list);
 	gtk_drag_finish (context, TRUE, FALSE, time);
 	gtk_tree_path_free (playlist->priv->tree_path);
@@ -1850,35 +1846,32 @@ totem_playlist_clear_with_compare (TotemPlaylist *playlist, GCompareFunc func,
 }
 
 static int
-totem_playlist_compare_with_volume (gpointer a, gpointer b)
+totem_playlist_compare_with_mount (gpointer a, gpointer b)
 {
-	GnomeVFSVolume *clear_volume = (GnomeVFSVolume *) b;
+	GMount *clear_mount = (GMount *) b;
 	const char *mrl = (const char *) a;
 
-	GnomeVFSVolume *volume;
-	GnomeVFSVolumeMonitor *monitor;
+	GMount *mount;
 	gboolean retval = FALSE;
 
-	monitor = gnome_vfs_get_volume_monitor ();
+	mount = totem_get_mount_for_media (mrl);
 
-	volume = totem_get_volume_for_media (mrl);
-
-	if (volume == clear_volume)
+	if (mount == clear_mount)
 		retval = TRUE;
 
-	if (volume != NULL)
-		gnome_vfs_volume_unref (volume);
+	if (mount != NULL)
+		g_object_unref (mount);
 
 	return retval;
 }
 
 void
-totem_playlist_clear_with_gnome_vfs_volume (TotemPlaylist *playlist,
-					    GnomeVFSVolume *volume)
+totem_playlist_clear_with_g_mount (TotemPlaylist *playlist,
+				   GMount *mount)
 {
 	totem_playlist_clear_with_compare (playlist,
-					   (GCompareFunc) totem_playlist_compare_with_volume,
-					   volume);
+					   (GCompareFunc) totem_playlist_compare_with_mount,
+					   mount);
 }
 
 char *
